@@ -3,6 +3,8 @@ import functools
 from threading import Thread
 import threading
 from time import sleep
+import traceback
+# from typing_extensions import Self
 import pika
 import retry
 import logging
@@ -37,6 +39,12 @@ class rabbitmq_helper():
             # Channel is already closed, so we can't ACK this message;
             # log and/or do something that makes sense for your app in this case.
             pass
+    def reject_message(self,channel,delivery_tag):
+        logger.info(f'reject_ack_message thread id: {threading.get_ident()}')
+        if channel.is_open:
+            channel.basic_reject(delivery_tag);
+        else:
+            pass        
 
     def receive_message(self,name):
         def wrap(func):
@@ -51,6 +59,10 @@ class rabbitmq_helper():
                 channel.connection.add_callback_threadsafe(cb)
             except Exception as e:
                 logger.error(e);
+        else:
+            cb = functools.partial(self.reject_message, channel, delivery_tag)
+            channel.connection.add_callback_threadsafe(cb)
+            # channel.conn
 
     def callback(self,ch, method, properties, body):
         flag = False;
